This subpackage will analyze and compare the runtime of two odoo versions.
The result will be reported and exposed as some python datastructure.

It will be configurable.

Work plan: https://gist.github.com/blaggacao/bbd58907516b5cb8690b3bfbe8ba2c21
